jupyter_server_terminals: A Jupyter Server Extension Providing Terminals
========================================================================

Description
-----------

A Jupyter Server Extension Providing Terminals.

License
-------

Modified BSD License (also known as New or Revised or 3-Clause BSD)

Upstream Contact
----------------

https://pypi.org/project/jupyter-server-terminals/

